summarylogtreecommitdiffstats
path: root/heli-x-wrapper.sh
diff options
context:
space:
mode:
author0b1001002021-12-30 00:04:55 +0100
committer0b1001002021-12-30 00:16:27 +0100
commitcc64ae73522851c4ea868ac746f38c3d73eb5d52 (patch)
treeff229f9653bee217470290126fe1144b7b8f8cfb /heli-x-wrapper.sh
parent226d41015764fa916929dfd03618f7545a058a51 (diff)
downloadaur-cc64ae73522851c4ea868ac746f38c3d73eb5d52.tar.gz
Let the server be started by an additional desktop file
Diffstat (limited to 'heli-x-wrapper.sh')
-rw-r--r--heli-x-wrapper.sh5
1 files changed, 4 insertions, 1 deletions
diff --git a/heli-x-wrapper.sh b/heli-x-wrapper.sh
index a98b5912de51..d5f7f78ebb21 100644
--- a/heli-x-wrapper.sh
+++ b/heli-x-wrapper.sh
@@ -24,5 +24,8 @@ else
fi
fi
-# execute the heli-x application
+# execute the heli-x application or server script
+if [ "$1" == "server" ]; then
+ APP_EXECUTABLE=${APP_EXECUTABLE/.sh/-Server.sh}
+fi
exec $APP_EXECUTABLE